pitchtools.IntervalObjectClass
==============================

.. inheritance-diagram:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.number

.. autoattribute:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__abs__

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__float__

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__hash__

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__int__

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__repr__

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__str__
